/*
** Module   : XCommonImpl
** Abstract : SAX attributes, reader, writer common fatures iplementation.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130214 Created initial version. Implementation is limited to the stubs to get the
**                  converted java code compiled.
** 002 CA  20130221 Added Deletable support. This resource doesn't have NEXT/PREV-SIBLING support. 
** 003 OM  20130304 Refactored isValid and isUnknown of WrappedResource to valid and unknown.
*/

package com.goldencode.p2j.xml;

import com.goldencode.p2j.util.*;

/**
 * Implementation the common features for XML related Progress objects.
 */
public class XCommonImpl
extends HandleChain
implements XCommon
{
   // Attributes
   /**
    * Gets the value of the XML schema file for elements with no namespaces.  
    *
    * @return   The value of the nonamespace-schema-location attribute.
    */
   @Override
   public character getNonamespaceSchemaLocation()
   {
      return new character();
   }
   
   /**
    * Setting the new value for the nonamespace-schema-location attribute.
    * 
    * @param    location
    *           New value of the nonamespace-schema-location attribute to set.
    */
   @Override
   public void setNonamespaceSchemaLocation(character location)
   {
      // TODO:
      return;
   }
   
   /**
    * Setting the new value for the nonamespace-schema-location attribute.
    * 
    * @param    location
    *           New value of the nonamespace-schema-location attribute to set.
    */
   @Override
   public void setNonamespaceSchemaLocation(String location)
   {
      setNonamespaceSchemaLocation(new character(location));
   }
   
   // Methods
   /**
    * Reports if this object is valid for use.
    *
    * @return   <code>true</code> if we are valid (can be used).
    */
   @Override
   public boolean valid()
   {
      // TODO:
      return true;
   }

   /**
    * Reports if this object is unknown.
    *
    * @return   <code>true</code> if object is unknown.
    */
   @Override
   public boolean unknown()
   {
      // TODO:
      return true;
   }

   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    namespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical addSchemaLocation(String namespace, character location)
   {
      return addSchemaLocation(new character(namespace), location);
   }

   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    namespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical addSchemaLocation(character namespace, String location)
   {
      return addSchemaLocation(namespace, new character(location));
   }

   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    namespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical addSchemaLocation(String namespace, String location)
   {
      return addSchemaLocation(new character(namespace), new character(location));
   }

   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    namespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical addSchemaLocation(character namespace, character location)
   {
      // TODO:
      return new logical(true);
   }
   
   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(character name)
   {
      return removeAttribute(name, new character());
   }
   
   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(String name)
   {
      return removeAttribute(new character(name), new character());
   }
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(NumberType index)
   {
      return removeAttribute(index, new character());
   }
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(double index)
   {
      return removeAttribute(new integer(index), new character());
   }

   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(character name, character uri)
   {
      // TODO:
      return new logical(true);
   }

   /**
    * Removes the specified attribute.
    *
    * @param    name
    *           The name of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    *
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(String name, character uri)
   {
      return removeAttribute(new character(name), uri);
   }
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(NumberType index, character uri)
   {
      // TODO: specify only for SAX
      return new logical(true);
   }
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(double index, character uri)
   {
      return removeAttribute(new integer(index), uri);
   }

   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(character name, String uri)
   {
      return removeAttribute(name, new character(uri));
   }
   
   /**
    * Removes the specified attribute.
    * 
    * @param    name
    *           The name of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(String name, String uri)
   {
      return removeAttribute(new character(name), new character(uri));
   }
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(double index, String uri)
   {
      return removeAttribute(new integer(index), new character(uri));
   }
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    uri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   @Override
   public logical removeAttribute(NumberType index, String uri)
   {
      return removeAttribute(index, new character(uri));
   }

   /**
    * Delete the resource.
    */
   @Override
   protected void resourceDelete()
   {
      // TODO Auto-generated method stub
   }

   /**
    * Check if this resource supports the PREV-SIBLING attribute.
    * 
    * @return   Always <code>false</code>.
    */
   @Override
   protected boolean hasPrevSibling()
   {
      return false;
   }
   
   /**
    * Check if this resource supports the NEXT-SIBLING attribute.
    * 
    * @return   Always <code>false</code>.
    */
   @Override
   protected boolean hasNextSibling()
   {
      return false;
   }
}
